summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qcanvasellipse_imp.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qcanvasellipse_imp.h')
-rw-r--r--kjsembed/qtbindings/qcanvasellipse_imp.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/kjsembed/qtbindings/qcanvasellipse_imp.h b/kjsembed/qtbindings/qcanvasellipse_imp.h
index 2a61a439..a0a03c8a 100644
--- a/kjsembed/qtbindings/qcanvasellipse_imp.h
+++ b/kjsembed/qtbindings/qcanvasellipse_imp.h
@@ -9,7 +9,7 @@
#include <kjsembed/jsobjectproxy_imp.h>
-class TQCanvasEllipse;
+class TTQCanvasEllipse;
/**
* Namespace containing the KJSEmbed library.
@@ -17,11 +17,11 @@ class TQCanvasEllipse;
namespace KJSEmbed {
/**
* Wrapper class for TQCanvasEllipse methods.
*
* @author Richard Moore, rich@kde.org
*/
-class QCanvasEllipseImp : public JSProxyImp
+class TQCanvasEllipseImp : public JSProxyImp
{
public:
/** Enumerates the constructors supported by this class. */
@@ -48,8 +48,8 @@ public:
Method_Last = -1
};
- QCanvasEllipseImp( KJS::ExecState *exec, int id, bool constructor=false );
- ~QCanvasEllipseImp();
+ TQCanvasEllipseImp( KJS::ExecState *exec, int id, bool constructor=false );
+ ~TQCanvasEllipseImp();
/**
* Adds the static bindings for this class to the specified Object. The
@@ -63,15 +63,15 @@ public:
*/
static void addBindings( KJS::ExecState *exec, KJS::Object &object );
- static TQCanvasEllipse *toQCanvasEllipse( KJS::Object &object );
+ static TTQCanvasEllipse *toTQCanvasEllipse( KJS::Object &object );
//
// Constructors implemented by this class.
//
- KJS::Object QCanvasEllipse_1( KJS::ExecState *exec, const KJS::List &args );
- KJS::Object QCanvasEllipse_2( KJS::ExecState *exec, const KJS::List &args );
- KJS::Object QCanvasEllipse_3( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQCanvasEllipse_1( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQCanvasEllipse_2( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQCanvasEllipse_3( KJS::ExecState *exec, const KJS::List &args );
//
// Methods implemented by this class.
@@ -104,7 +104,7 @@ public:
virtual KJS::Value call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args );
private:
- TQCanvasEllipse *instance; // Temp
+ TTQCanvasEllipse *instance; // Temp
int id;
bool cons;
};
@@ -17,11 +17,11 @@ class TQCanvasEllipse;
namespace KJSEmbed {
/**
- * Wrapper class for TQCanvasEllipse methods.
+ * Wrapper class for TTQCanvasEllipse methods.
*
* @author Richard Moore, rich@kde.org